@@ -3,15 +3,10 @@ from django.forms import (BaseModelForm, model_to_dict, fields_for_model,
                           save_instance, ValidationError, Media,
                           MediaDefiningClass)
 
-from django.contrib.localflavor.generic.forms import (
-                          DEFAULT_DATE_INPUT_FORMATS,
-                          DEFAULT_DATETIME_INPUT_FORMATS,
-)
-
 from .fields import *
 from .forms import *
 from .models import *
 from .widgets import *
 from . import gis
 
-__version__ = '1.0'
+__version__ = '1.1'
