@@ -1,4 +1,3 @@
-import re
 from collections import defaultdict
 from contextlib import contextmanager
 
@@ -7,68 +6,9 @@ from django.forms.forms import BoundField
 from django.forms.util import ErrorList
 from django.template import (Library, Node, Variable,
                              TemplateSyntaxError, VariableDoesNotExist)
+from django.template.base import token_kwargs
 from django.template.loader import get_template
-
-try:
-    from django.utils.functional import empty
-except ImportError:
-    empty = None  # noqa
-
-try:
-    from django.template.base import token_kwargs
-except ImportError:
-    # Regex for token keyword arguments
-    kwarg_re = re.compile(r"(?:(\w+)=)?(.+)")
-
-    def token_kwargs(bits, parser, support_legacy=False):  # noqa
-        """
-        A utility method for parsing token keyword arguments.
-
-        :param bits: A list containing remainder of the token (split by spaces)
-            that is to be checked for arguments. Valid arguments will be removed
-            from this list.
-
-        :param support_legacy: If set to true ``True``, the legacy format
-            ``1 as foo`` will be accepted. Otherwise, only the standard ``foo=1``
-            format is allowed.
-
-        :returns: A dictionary of the arguments retrieved from the ``bits`` token
-            list.
-
-        There is no requirement for all remaining token ``bits`` to be keyword
-        arguments, so the dictionary will be returned as soon as an invalid
-        argument format is reached.
-        """
-        if not bits:
-            return {}
-        match = kwarg_re.match(bits[0])
-        kwarg_format = match and match.group(1)
-        if not kwarg_format:
-            if not support_legacy:
-                return {}
-            if len(bits) < 3 or bits[1] != 'as':
-                return {}
-
-        kwargs = {}
-        while bits:
-            if kwarg_format:
-                match = kwarg_re.match(bits[0])
-                if not match or not match.group(1):
-                    return kwargs
-                key, value = match.groups()
-                del bits[:1]
-            else:
-                if len(bits) < 3 or bits[1] != 'as':
-                    return kwargs
-                key, value = bits[2], bits[0]
-                del bits[:3]
-            kwargs[key] = parser.compile_filter(value)
-            if bits and not kwarg_format:
-                if bits[0] != 'and':
-                    return kwargs
-                del bits[:1]
-        return kwargs
-
+from django.utils.functional import empty
 
 register = Library()
 
@@ -377,7 +317,7 @@ class ModifierBase(BaseFormNode):
         if self.options['with']:
             extra_context = dict([
                 (name, var.resolve(context))
-                for name, var in self.options['with'].iteritems()])
+                for name, var in self.options['with'].items()])
             config.configure(self.context_config_name,
                              extra_context, filter=filter)
         return u''
@@ -502,7 +442,7 @@ class BaseFormRenderNode(BaseFormNode):
         if self.options['with']:
             extra_context.update(dict([
                 (name, var.resolve(context))
-                for name, var in self.options['with'].iteritems()]))
+                for name, var in self.options['with'].items()]))
 
         return extra_context
 
@@ -613,11 +553,11 @@ class FormRowNode(BaseFormRenderNode):
 @contextmanager
 def attributes(widget, **kwargs):
     old = {}
-    for name, value in kwargs.iteritems():
+    for name, value in kwargs.items():
         old[name] = getattr(widget, name, empty)
         setattr(widget, name, value)
     yield widget
-    for name, value in old.iteritems():
+    for name, value in old.items():
         if value is not empty:
             setattr(widget, name, value)
 
