@@ -1,9 +1,12 @@
+from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.template import Context, Template
+from django.test import TestCase
 from django.utils.translation import ugettext_lazy as _
 
 import floppyforms as forms
-from .base import FloppyFormsTestCase
+
+from .base import InvalidVariable
 
 
 def render(template, context=None):
@@ -31,8 +34,10 @@ class RegistrationForm(forms.Form):
     firstname = forms.CharField(label=_(u'Your first name?'))
     lastname = forms.CharField(label=_(u'Your last name:'))
     username = forms.CharField(max_length=30)
-    password = forms.CharField(widget=forms.PasswordInput,
-        help_text=_(u'Make sure to use a secure password.'))
+    password = forms.CharField(
+        widget=forms.PasswordInput,
+        help_text=_(u'Make sure to use a secure password.'),
+    )
     password2 = forms.CharField(label=_(u'Retype password'), widget=forms.PasswordInput)
     age = forms.IntegerField(required=False)
 
@@ -46,7 +51,7 @@ class RegistrationForm(forms.Form):
             raise ValidationError(u'Please correct the errors below.')
 
 
-class PLayoutTests(FloppyFormsTestCase):
+class PLayoutTests(TestCase):
     def test_default_layout_is_same_as_p_layout(self):
         form = RegistrationForm()
         default = render('{% form form %}', {'form': form})
@@ -155,7 +160,7 @@ class PLayoutTests(FloppyFormsTestCase):
         """)
 
 
-class TableLayoutTests(FloppyFormsTestCase):
+class TableLayoutTests(TestCase):
     def test_layout(self):
         form = RegistrationForm()
         with self.assertTemplateUsed('floppyforms/layouts/table.html'):
@@ -247,7 +252,7 @@ class TableLayoutTests(FloppyFormsTestCase):
         """)
 
 
-class UlLayoutTests(FloppyFormsTestCase):
+class UlLayoutTests(TestCase):
     def test_layout(self):
         form = RegistrationForm()
         with self.assertTemplateUsed('floppyforms/layouts/ul.html'):
@@ -325,3 +330,30 @@ class UlLayoutTests(FloppyFormsTestCase):
         self.assertHTMLEqual(rendered, """
         <input type="hidden" name="hide" id="id_hide" required>
         """)
+
+
+class TemplateStringIfInvalidTests(TestCase):
+    '''
+    Regression tests for issue #37.
+    '''
+    def setUp(self):
+        self.original_TEMPLATE_STRING_IF_INVALID = settings.TEMPLATE_STRING_IF_INVALID
+
+    def tearDown(self):
+        settings.TEMPLATE_STRING_IF_INVALID = self.original_TEMPLATE_STRING_IF_INVALID
+
+    def test_none(self):
+        settings.TEMPLATE_STRING_IF_INVALID = None
+
+        layout = OneFieldForm().as_p()
+        self.assertHTMLEqual(layout, """
+        <p><label for="id_text">Text:</label> <input type="text" name="text" id="id_text" required /></p>
+        """)
+
+    def test_non_empty(self):
+        settings.TEMPLATE_STRING_IF_INVALID = InvalidVariable(u'INVALID')
+
+        layout = OneFieldForm().as_p()
+        self.assertHTMLEqual(layout, """
+        <p><label for="id_text">Text:</label> <input type="text" name="text" id="id_text" required /></p>
+        """)
