@@ -1,11 +1,12 @@
 from django.forms import TextInput
 from django.forms.formsets import formset_factory
 from django.template import Context, Template, TemplateSyntaxError
+from django.test import TestCase
 
 import floppyforms as forms
 from floppyforms.templatetags.floppyforms import (FormConfig, ConfigFilter,
-    FormNode, RowModifier, FieldModifier)
-from .base import FloppyFormsTestCase
+                                                  FormNode, RowModifier,
+                                                  FieldModifier)
 
 
 def render(template, context=None, config=None):
@@ -50,7 +51,7 @@ class HardcodedForm(forms.Form):
     name = forms.CharField(widget=HardcodedWidget())
 
 
-class FormConfigNodeTests(FloppyFormsTestCase):
+class FormConfigNodeTests(TestCase):
     def test_enforce_form_tag(self):
         render('{% form myform using %}{% formconfig row using "my_row_template.html" %}{% endform %}')
         with self.assertRaises(TemplateSyntaxError):
@@ -224,7 +225,7 @@ class FormConfigNodeTests(FloppyFormsTestCase):
             'field.html')
 
 
-class FormTagTests(FloppyFormsTestCase):
+class FormTagTests(TestCase):
     def test_valid_syntax(self):
         render('{% form myform %}')
         render('{% form myform using "myform_layout.html" %}')
@@ -273,8 +274,8 @@ class FormTagTests(FloppyFormsTestCase):
             {% form myform using %}
                 <ins>{% cycle "foo" "bar" as value %}</ins>
             {% endform %}
-            <del>{{ value }}</del>
-            """), '<ins>foo</ins><del />')
+            <del>{% firstof value "NO VALUE" %}</del>
+            """), '<ins>foo</ins><del>NO VALUE</del>')
         # form variable equals the first argument in form tag
         self.assertHTMLEqual(render("""
             {% form myform using %}{% if myform == form %}Equals!{% endif %}{% endform %}
@@ -288,7 +289,8 @@ class FormTagTests(FloppyFormsTestCase):
             """, {'f1': SimpleForm(), 'f2': SimpleForm()}), 'Equals!')
 
         # none forms are not included in form list
-        self.assertHTMLEqual(render("""
+        self.assertHTMLEqual(
+            render("""
             {% form f1 nothing f2 more_of_nothing using %}
                 {% if f1 == forms.0 and f2 == forms.1 %}
                 {% if forms.2 == None and more_of_nothing == None %}
@@ -419,7 +421,7 @@ class FormTagTests(FloppyFormsTestCase):
             """)
 
 
-class FormRowTagTests(FloppyFormsTestCase):
+class FormRowTagTests(TestCase):
     def test_valid_syntax(self):
         render('{% formrow myform.field %}')
         render('{% formrow myform.field using "myrow_layout.html" %}')
@@ -576,7 +578,7 @@ class FormRowTagTests(FloppyFormsTestCase):
         """)
 
 
-class FormFieldTagTests(FloppyFormsTestCase):
+class FormFieldTagTests(TestCase):
     def test_valid_syntax(self):
         render('{% formfield myform.name %}')
 
@@ -612,27 +614,30 @@ class FormFieldTagTests(FloppyFormsTestCase):
     def test_configure_template_with_extra_context(self):
         form = SimpleForm()
         with self.assertTemplateUsed('simple_formfield_tag.html'):
-            self.assertHTMLEqual(render("""{% form myform using %}
+            self.assertHTMLEqual(
+                render("""{% form myform using %}
                 {% formconfig field using "simple_formfield_tag.html" %}
                 {% formfield form.name with extra_argument="I want bacon!" %}
             {% endform %}""", {'myform': form}),
-            "Type: text Extra argument: I want bacon!")
+                "Type: text Extra argument: I want bacon!")
 
     def test_configure_extra_context(self):
         form = SimpleForm()
-        self.assertHTMLEqual(render("""{% form myform using %}
+        self.assertHTMLEqual(
+            render("""{% form myform using %}
             {% formconfig field with extra_argument="I want spam!" %}
             {% formconfig field with extra_argument="I want ham!" %}
             {% formfield form.name using "simple_formfield_tag.html" %}
         {% endform %}""", {'myform': form}),
-        "Type: text Extra argument: I want ham!")
+            "Type: text Extra argument: I want ham!")
 
         context = Context({'myform': form})
-        self.assertHTMLEqual(render("""{% form myform using %}
+        self.assertHTMLEqual(
+            render("""{% form myform using %}
             {% formconfig field using "simple_formfield_tag.html" with extra_argument="I want ham!" %}
             {% formfield form.name %}
         {% endform %}""", context),
-        "Type: text Extra argument: I want ham!")
+            "Type: text Extra argument: I want ham!")
 
     def test_change_widget(self):
         form = SimpleForm()
@@ -650,7 +655,7 @@ class FormFieldTagTests(FloppyFormsTestCase):
         {% endform %}""", {'myform': form}), """Hardcoded widget.""")
 
 
-class WidgetTagTest(FloppyFormsTestCase):
+class WidgetTagTest(TestCase):
     def test_widget_tag(self):
         class MediaWidget(forms.TextInput):
             template_name = 'media_widget.html'
